@@ -112,6 +112,40 @@ And this will produce
 
 ### Composable Elements
 
+Besides the basic elements, elements can be composed into a logic group we called composed elements.
+When composing new elements, the upper-left conner is given in the target coordinate, and a new pixel
+based coordinate which has the upper-left conner defined as `(0,0)` is used for further element composition purpose.
+
+For example, we can have an element which includes a dot and its coordinate.
+
+```rust
+use plotters::prelude::*;
+
+fn main() -> Result<(), Box<dyn std::error::Error>> {
+    let backend = BitMapBackend::new("examples/outputs/4.png", (640, 480));
+    // A backend object can be converted into a drawing area
+    let root:DrawingArea<_,_> = backend.into();
+    root.fill(&RGBColor(255,255,255))?;
+
+    let root = root.apply_coord_spec(RangedCoord::<RangedCoordf32, RangedCoordf32>::new(0f32..1f32, 0f32..1f32, (0..640, 0..480)));
+    let font = Into::<FontDesc>::into("DejaVu Serif").resize(15.0);
+
+    let dot_and_label = |x:f32,y:f32| {
+        return EmptyElement::at((x,y))
+               + Circle::new((0,0), 3, Into::<ShapeStyle>::into(&RGBColor(0,0,0)).filled())
+               + OwnedText::new(format!("({:.2},{:.2})", x, y), (10, 0), &font);
+    };
+
+    root.draw(&dot_and_label(0.5, 0.6))?;
+    root.draw(&dot_and_label(0.25, 0.33))?;
+    root.draw(&dot_and_label(0.8, 0.8))?;
+    root.close()?;
+    return Ok(());
+}
+```
+
+![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/4.png)
+
 ### Plotting
 
 ## Extending Plotters
